==> huaweicloudsdkprojectman-3.1.109-py2.py3-none-any.whl: huaweicloudsdkprojectman/v4/model/show_issues_wrok_flow_config_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowIssuesWrokFlowConfigResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'workflows': 'list[ScrumStatusFlowVo]'
    }

    attribute_map = {
        'workflows': 'workflows'
    }

    def __init__(self, workflows=None):
        """ShowIssuesWrokFlowConfigResponse

        The model defined in huaweicloud sdk

        :param workflows: 流转数据
        :type workflows: list[:class:`huaweicloudsdkprojectman.v4.ScrumStatusFlowVo`]
        """
        
        super(ShowIssuesWrokFlowConfigResponse, self).__init__()

        self._workflows = None
        self.discriminator = None

        if workflows is not None:
            self.workflows = workflows

    @property
    def workflows(self):
        """Gets the workflows of this ShowIssuesWrokFlowConfigResponse.

        流转数据

        :return: The workflows of this ShowIssuesWrokFlowConfigResponse.
        :rtype: list[:class:`huaweicloudsdkprojectman.v4.ScrumStatusFlowVo`]
        """
        return self._workflows

    @workflows.setter
    def workflows(self, workflows):
        """Sets the workflows of this ShowIssuesWrokFlowConfigResponse.

        流转数据

        :param workflows: The workflows of this ShowIssuesWrokFlowConfigResponse.
        :type workflows: list[:class:`huaweicloudsdkprojectman.v4.ScrumStatusFlowVo`]
        """
        self._workflows = workflows

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowIssuesWrokFlowConfigResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkprojectman-3.1.145-py2.py3-none-any.whl: huaweicloudsdkprojectman/v4/model/show_issues_wrok_flow_config_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowIssuesWrokFlowConfigResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'workflows': 'list[ScrumStatusFlowVo]'
    }

    attribute_map = {
        'workflows': 'workflows'
    }

    def __init__(self, workflows=None):
        r"""ShowIssuesWrokFlowConfigResponse

        The model defined in huaweicloud sdk

        :param workflows: 流转数据
        :type workflows: list[:class:`huaweicloudsdkprojectman.v4.ScrumStatusFlowVo`]
        """
        
        super(ShowIssuesWrokFlowConfigResponse, self).__init__()

        self._workflows = None
        self.discriminator = None

        if workflows is not None:
            self.workflows = workflows

    @property
    def workflows(self):
        r"""Gets the workflows of this ShowIssuesWrokFlowConfigResponse.

        流转数据

        :return: The workflows of this ShowIssuesWrokFlowConfigResponse.
        :rtype: list[:class:`huaweicloudsdkprojectman.v4.ScrumStatusFlowVo`]
        """
        return self._workflows

    @workflows.setter
    def workflows(self, workflows):
        r"""Sets the workflows of this ShowIssuesWrokFlowConfigResponse.

        流转数据

        :param workflows: The workflows of this ShowIssuesWrokFlowConfigResponse.
        :type workflows: list[:class:`huaweicloudsdkprojectman.v4.ScrumStatusFlowVo`]
        """
        self._workflows = workflows

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowIssuesWrokFlowConfigResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
